/****************************************************************************
Date: 7/5/95
File: inttimer.hpp
Description: Interval Timer
	Provides timing interval in seconds, interval must be > 0.
Public Members:
		INTERVALTIMER()
		VOID	Start(USHORT unSeconds);
		BOOL	IsExpired();
		VOID	Stop();
		static	VOID	Update();

*****************************************************************************/
#ifndef INTTIMER_HPP
#define INTTIMER_HPP

#pragma check_stack( off )
#pragma check_pointer( off )

#include "loctypes.h"

class INTERVALTIMER {
private:
	static ULONG	ulClock;		// running counter

	enum { INTERVALTIMER_TICKSPERSEC = 18 }; // dos tick ~18 x per sec

	ULONG		ulExpireTicks;		// Note: make 0 to stop
public:
	INTERVALTIMER(): ulExpireTicks(0) { }

	VOID	Start(USHORT unSeconds) {
		ulExpireTicks = ulClock +
				(INTERVALTIMER_TICKSPERSEC * unSeconds);
	}

	BOOL	IsExpired() {
		if (ulExpireTicks == 0) {
			return BOOL_FALSE;
		}
		return (BOOL) (ulClock >= ulExpireTicks);
	}

	VOID	Stop() {
		ulExpireTicks = 0;
	}

	static VOID Update() {
		++ulClock;
	}
};
#endif
