/****************************************************************************
Date: 11/26/2001
File: radio.cpp

Description:	RADIO and RADIOSYSTEM classes

	RADIO = base class for all radio drivers
	RADIOSYSTEM class has a RADIO driver plus frequency converters

History:
	11/25/97
	12/24/98 added FT-847
	6/3/00	 added ICOM IC-821
	7/20/00	 added FT-100
	6/14/2001 added Kenwood TS-790
	7/1/2001 added (merged) FT-817 from G6LVB
	9/9/2001 added TS-2000
	11/26/2001 fixed FT-847 problem (missing "break")
	
*****************************************************************************/
// Radio classes
#include "radio.hpp"
#include "kenwood.hpp"
#include "mbradio.hpp"
#include "ft736.hpp"
#include "ft847.hpp"
#include "ft100.hpp"
#include "ft817.hpp"	// Mar 26 2001  G6LVB
#include "icom.hpp"
#include "ts790.hpp"
#include "ts2000.hpp"

// Create a new radio driver
RADIO* RADIO::NewInstance(const RADIOPARAMS& Params) {

	RADIO* pRadio;
	switch(Params.eType) {
	case RADIOTYPE_NULL:
		pRadio = new RADIO();	// dummy driver
		break;

	case RADIOTYPE_KENWOOD:
		pRadio = new KENWOOD(Params);
		break;

	case RADIOTYPE_MICBUTTON:
		pRadio = new MICBUTTONRADIO(Params);
		break;

	case RADIOTYPE_FT736:
		pRadio = new FT736(Params);
		break;

	case RADIOTYPE_FT847:
		pRadio = new FT847(Params);
		break;

	case RADIOTYPE_FT100:
		pRadio = new FT100(Params);
		break;

	case RADIOTYPE_FT817:		// G6LVB mar 26 2001
		pRadio = new FT817(Params);
		break;
		
	case RADIOTYPE_ICOM:
		pRadio = new ICOM(Params);
		break;
		
	case RADIOTYPE_TS790:
		pRadio = new TS790(Params);
		break;

	case RADIOTYPE_TS2000:
		pRadio = new TS2000(Params);
		break;

/**** ADD THESE LATER
	RADIOTYPE_IC735
	RADIOTYPE_ICR7000
	RADIOTYPE_IC970
*****/
	default:
		// unknown type
		pRadio = NULL;
		break;

	} // end switch()

	// Check to make sure driver is OK
	// if not return NULL
	if (pRadio != NULL) {
		if (pRadio->IsOperational() == BOOL_FALSE) {
			delete pRadio;
			pRadio = NULL;
		}
	}
	return pRadio;
}

// Create a new RADIOSYSTEM
RADIOSYSTEM* RADIOSYSTEM::NewInstance(const RADIOPARAMS& Params) {
	RADIO* pRadio = RADIO::NewInstance(Params);
	if (pRadio == NULL) {
		return NULL;
	}
	return new RADIOSYSTEM(pRadio, Params);
}
