/**************************************************************************
date: 8/19/96
file: slink.hpp

title:    SERIALLINK - Serial Communications Link class
  
public:
	SERIALLINK(	CHAR*	pRxBuffer,
			UINT	unRxBufferSize,
			CHAR	cEndOfMsg,
			ULONG	ulTimeOut)
	VOID	Send(const CHAR* pData, size_t TxCount=0)
	UINT	Receive()	// returns # of chars in user buffer
	BOOL	TimeOut()	// BOOL_TRUE if timed-out
	VOID	Reset()		// use after timeout to clear partial msgs
	~SERIALLINK()

	// from COMDRV base class
	BOOL	Open( 	UINT	unComPort,
			UINT	unBitRate,
                        UINT    unDataBits,
                        UARTPARITY eParity,
                        UINT    unStopBits,
			UINT	unIRQ 		= DEFAULTIRQ,
			IOADDRESS Address 	= DEFAULTADDRESS)
        VOID    Putc(CHAR cChar)
	INT	Getc() 
        VOID    Write(const CHAR* pUserData, UINT unCount)
	INT	Read(CHAR* pUserBuffer, UINT unMaxCount)
	VOID	ClearBuffers()
	VOID	Close()

description:
	Provides message-oriented, serial communications link to a serial 
	port device. Send() starts a response "timeout" timer. This can
	be checked with TimeOut(). The EndOfMsg character is used
	to recognize a complete receive message. It is also automatically
	appended to messages sent with Send().

	This class is publicly derived from the COMDRV class. 
	

history:  AJM initial version
**************************************************************************/
#ifndef SLINK_HPP
#define SLINK_HPP

#pragma check_stack( off )
#pragma check_pointer( off )

#include <string.h>	// uses strlen()
#include "loctypes.h"	// local types
#include "comdrv.hpp"	// COMDRV base class
#include "inttimer.hpp"	// INTERVALTIMER class


class SERIALLINK : public COMDRV {
private:
	INTERVALTIMER Timer;
	const USHORT	unTimeOut;
	CHAR* const	pRxBuffer;
	CHAR* pRxData;
	const UINT	unRxBufferSize;
	UINT  	unRxCount;
	const CHAR	cEndOfMsg;

public:
	SERIALLINK(	CHAR*	pRxBuffer,
			UINT	unRxBufferSize,
			CHAR	cEndOfMsg,
			USHORT	unTimeOut);
	VOID	Send(const CHAR* pData, size_t TxCount=0);
	UINT	Receive();
	BOOL	TimeOut();
	VOID	Reset();
	~SERIALLINK();
};
#endif // slink.hpp
