/****************************************************************************
Copyright 1997 Anthony Monteiro

Date: 11/19/97
File: xpdranlg.hpp
Description: 	NON-INVERTING ANALOG TRANSPONDER CLASS

	On a non-inverting analog transponder the output frequency 
	tracks the input frequency:

		InputFreq = TRANSLATION + OutputFreq
		OuputFreq = InputFreq - TRANSLATION

	The input and output modulation mode is always the same.

History:
	11/19/97 Release 1.0
*****************************************************************************/
#ifndef XPDRANLG_HPP
#define XPDRANLG_HPP

#include "loctypes.h"
#include "xpdrbase.hpp"		// TRANSPONDER base class

class NONINVERTINGTRANSPONDER : public TRANSPONDER {
private:
	const DOUBLE	dTranslation;

public:
	NONINVERTINGTRANSPONDER(const TRANSPONDERPARAMS& Params) :
		dTranslation(Params.dParam) {

		SetOutputFreq(Params.dOutFreq);
		SetOutputMode(Params.eOutMode);
	}

	VOID	SetInputFreq(DOUBLE dFreq) {
		TRANSPONDER::dInputFreq = dFreq;
		TRANSPONDER::dOutputFreq = dFreq - dTranslation;
	}

	VOID	SetOutputFreq(DOUBLE dFreq) {
		TRANSPONDER::dOutputFreq = dFreq;
		TRANSPONDER::dInputFreq = dTranslation + dFreq;
	}

	VOID	SetInputMode(MODULATION eMode) {
		TRANSPONDER::eOutputMode = eMode;
		TRANSPONDER::eInputMode = eMode;
	}

	VOID	SetOutputMode(MODULATION eMode) {
		TRANSPONDER::eOutputMode = eMode;
		TRANSPONDER::eInputMode = eMode;
	}
};
#endif
// end xpdranlg.hpp
